C -----------------------------------------------------------------------
C    GRADI.F
C subroutine per la conversione di un angolo misurato in radianti
C allo stesso misurato in gradi, primi e secondi
C
C dati di input
C x      -  angolo in radianti 
C dati di output
C xgradi -  parte in gradi dell'angolo
C xprimi -  parte in primi dell'angolo
C xsecondi - parte in secondi dell'angolo
C l'angolo in gradi scritto come x^o     p'     s''       sara' dunque 
C                                xgradi xprimi xsecondi
C ------------------------------------------------------------------------

        subroutine gradi(x,xgradi,xprimi,xsecondi)

        implicit none
        integer xgradi,xprimi,xsecondi
        real*8 x,diffgradi,diffprimi,dx,dxx
        x=x*180./(2.*dasin(1.d0))
        xgradi=x
        diffgradi=x-xgradi
        dx=diffgradi*60.
        xprimi=dx
        diffprimi=dx-xprimi
        dxx=diffprimi*60. +0.5d0
        xsecondi=dxx

        return
        end
  
